/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.Logout");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("net.jazz.ajax.toolbox.lang.internal.Lang");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.team.repository.web.client.internal.licensing");
dojo.require("com.ibm.team.repository.web.client.session.Session");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.require("com.ibm.team.repository.web.ui.internal.Util");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");

var InternalMessages			= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal", "Messages");
var ServiceabilityMessages		= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var checkNotNull				= net.jazz.ajax.toolbox.lang.checkNotNull;
var MessageFormatter			= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var getAuthenticatedContributor	= com.ibm.team.repository.web.client.session.getAuthenticatedContributor;
var getExpirationInfo			= com.ibm.team.repository.web.client.internal.licensing.getExpirationInfo;
var getLicenseInfo				= com.ibm.team.repository.web.client.internal.licensing.getLicenseInfo;
var SRH							= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var FORM_SESSION_COOKIE			= "JazzFormAuth";
var X_AUTH_MSG                  = "X-com-ibm-team-repository-web-auth-msg";
var DEFAULT_LOGOUT_URI			= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/templates/loggedout.html");

function getAuthMethod() {
	return document.cookie.match(FORM_SESSION_COOKIE + "=") ? "FORM" : "BASIC";
}

function getBasicLogoutLinkUri() {
	return com.ibm.team.repository.web.logouturi;
}

function getFormLogoutLinkUri() {
	var uri = com.ibm.team.repository.web.logouturi;
	if (uri == null) {
		uri = DEFAULT_LOGOUT_URI;
	}
	uri += "?path=" + escape(this.location.pathname + this.location.search + this.location.hash);
	return uri;
}

/**
 * Displays the logged in user's screen name and Log out link in the banner.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.Logout",
	[dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/templates/Logout.html"),
	
	/**
	 * Fill in the dynamic elements of the header nav.
	 */
	postCreate: function() {
		com.ibm.rational.report.web.core.app.internal.Logout.superclass.postCreate.apply(this);
		checkNotNull(this.userIdContainer, "this.useridContainer");
		checkNotNull(this.logoutLinkContainer, "this.logoutLinkContainer");
		
		if (this.loggedInUser == null) {
			this.loggedInUser = getAuthenticatedContributor().name;
		}
		this.userIdContainer.appendChild(document.createTextNode(this.loggedInUser));
		
		if (getAuthMethod() == "FORM") {
			this._addFormLogoutLink();
		}
		else if (getBasicLogoutLinkUri()) {
			this._addBasicLogoutLink();
		}
		
		this._msgFormatter = new MessageFormatter(null);
		
		dojo.subscribe(com.ibm.team.repository.web.internal.events.licenseChange, this, "_showLicenseInfo");
		var self = this;
		setTimeout(
			function() {
				getLicenseInfo(new SRH(self, "_showLicenseInfo", "_showLicenseInfoErr"));
			}, 4000);
	},
	
	_showLicenseInfo: function(licenseInfo) {
		var disabledReason = dojo.getObject("serverLicense.disabledReason", false, licenseInfo || "");
		var expirationTime = dojo.getObject("serverLicense.expirationTime", false, licenseInfo || "");
		
		// if there's no expiration time, don't show anything
		if (!expirationTime && !disabledReason) {
			this.expirationInfo.innerHTML = "";
			this.expirationInfoSeparator.style.display = "none";
		} else if (disabledReason) {
			this.expirationInfo.className = "expirationWarning";
			this.expirationInfo.innerHTML = disabledReason;
		} else {
			var expirationInfo = getExpirationInfo(expirationTime);			
			if (expirationInfo.isExpired || expirationInfo.daysRemaining <= 14) {
				this.expirationInfo.className = "expirationWarning";
			} else {
				this.expirationInfo.className = "expirationInfo";
			}
			if (expirationInfo.isExpired) {
				this.expirationInfo.innerHTML = InternalMessages.TRIAL_LICENSE_EXPIRED;
			} else if (expirationInfo.daysRemaining === 0) {
				this.expirationInfo.innerHTML = InternalMessages.TRIAL_LICENSE_EXPIRE_TODAY;				
			} else {
				var daysLeft = expirationInfo.daysRemaining;
				if (daysLeft === 1) {
					this.expirationInfo.innerHTML = dojo.string.substitute(
						InternalMessages.TRIAL_LICENSE_EXPIRE_TOMORROW, [daysLeft]);
				} else {
					this.expirationInfo.innerHTML = dojo.string.substitute(
						InternalMessages.TRIAL_LICENSE_EXPIRE_SOON, [daysLeft]);				
				}
			}
			this.expirationInfoSeparator.style.display = "inline";
			this.expirationInfo.innerHTML += " ";
		}
	},
	
	_showLicenseInfoErr: function(error) {
		var msg = this._msgFormatter.formatErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_LICENSE_INFO, error);
		console.warn(msg);
	},
	
	_addBasicLogoutLink: function() {
		checkNotNull(getBasicLogoutLinkUri(), "getBasicLogoutLinkUri()");
		
		this.logoutLinkContainer.appendChild(document.createTextNode(" | "));
		
		var logoutLink = document.createElement("a");
		logoutLink.href = getBasicLogoutLinkUri(true);
		
		logoutLink.appendChild(document.createTextNode(InternalMessages.LOGOUT_LINK));
		
		this.logoutLinkContainer.appendChild(logoutLink);
	},
	
	_addFormLogoutLink: function () {
		this.logoutLinkContainer.appendChild(document.createTextNode(" | "));
		
		var logoutLink = document.createElement("a");
		var logoutURI = getFormLogoutLinkUri();
		logoutLink.href = "javascript:{}";
		logoutLink.onclick = function () {
			var bindArgs = {
				url: net.jazz.ajax._contextRoot + "/auth/logout",
				handleAs: "json",
				headers: {
					accept: "text/json"
				},
				preventCache: dojo.isIE,
				handle: function(response, ioArgs) {
					document.location.reload();
					var url = window.location.href;
					var index = url.lastIndexOf("#");
					if (index > 0) {
						window.location = url.substring(0, index);
					}
				}
			};
			dojo.xhrPost(bindArgs);
		};
		
		logoutLink.appendChild(document.createTextNode(InternalMessages.LOGOUT_LINK));
		this.logoutLinkContainer.appendChild(logoutLink);
	}
	
});

})();
