/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.admin.ViewUserViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.client.internal.UserClient");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.Util");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");

var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var CoreAdminMessages	    = dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.admin", "Messages");
var UserClient				= com.ibm.rational.report.web.core.client.internal.UserClient;
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var Util					= com.ibm.rational.report.web.core.app.internal.Util;
var ServiceResponseHandler	= com.ibm.team.repository.web.transport.ServiceResponseHandler;

var USER_TITLE_IMG_SRC	= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/user.gif");

/**
 * Displays the Edit User view.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.admin.ViewUserViewer",
	[dijit._Widget, dijit._Templated], {
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/admin/templates/ViewUserViewer.html"),
		
	constructor: function(args) {
		this._controller = args.controller;
		this._userName = args.userName;
		this._viewUserProfile = args.viewUserProfile;
	},
	
	postCreate: function() {
		Util.removeChildren(this.pageTitle);
		var pageTitleIcon = document.createElement("img");
		pageTitleIcon.src = USER_TITLE_IMG_SRC;
		this.pageTitle.appendChild(pageTitleIcon);
		this.pageTitle.appendChild(document.createTextNode(this._userName));
		
		Util.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
		
		Util.removeChildren(this.editUserIdLabel);
		this.editUserIdLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_USER_ID_LABEL));
	
		Util.removeChildren(this.editUserFirstNameLabel);
		this.editUserFirstNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_FIRST_NAME_LABEL));
		
		Util.removeChildren(this.editUserLastNameLabel);
		this.editUserLastNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_LAST_NAME_LABEL));
		
		Util.removeChildren(this.editUserScreenNameLabel);
		this.editUserScreenNameLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_SCREEN_NAME_LABEL));
		
		Util.removeChildren(this.editUserEmailLabel);
		this.editUserEmailLabel.appendChild(document.createTextNode(CoreAdminMessages.EDIT_USER_EMAIL_LABEL));

		this._msgFormatter = new MessageFormatter(this.messageArea);
		this._adminUser = "";
		this._loginUser = "";
		
		var self = this;
		
		var srh = new ServiceResponseHandler(this, "_displayUserAttribute", "_getUserAttributesError");
		UserClient.getUserAttributes(srh, {name: this._userName});
		
		var self = this;
		
		dojo.connect(this.closeButton, "onclick",
			function(e) {
				e.preventDefault();
				self._exitPage();
			}
		);
		
		dojo.connect(this.editUserForm, "onkeyup",
			function(e) {
				e.preventDefault();
				self.validateUserInput();
			}
		);
	},
	
	_displayUserAttribute: function(userAttr) {
		this.editUserId.value = userAttr.name;
		this.editUserFirstName.value = userAttr.firstName;
		this.editUserLastName.value = userAttr.lastName;
	   	this.editUserScreenName.value = userAttr.screenName;	    	    	    
	    this.editUserEmail.value = userAttr.email;
	},
	
	_getUserAttributesError: function(error) {
		var msg = dojo.string.substitute(ServiceabilityMessages.FAILED_TO_RETRIEVE_USER_PROFILE, [dojo.trim(this._userName)]);
		this._msgFormatter.displayErrorMessage(msg, error);
	},
		
	_exitPage: function() {
		this.controller.manageUsers(); 
	}
	
});

})();