/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.view.security.GrantPermissionViewer");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("com.ibm.rational.report.web.core.app.internal.MessageFormatter");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.SelectionWidget");
dojo.require("com.ibm.rational.report.web.core.client.internal.SecurityClient");
dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.view.security", "Messages");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");

var ServiceabilityMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.serviceability", "Messages");
var CommonMessages	    	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var SecurityMessages	    = dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.view.security", "Messages");
var MessageFormatter		= com.ibm.rational.report.web.core.app.internal.MessageFormatter;
var SecurityClient			= com.ibm.rational.report.web.core.client.internal.SecurityClient;
var ServiceResponseHandler 	= com.ibm.team.repository.web.transport.ServiceResponseHandler;
var Util					= com.ibm.rational.report.web.core.app.internal.Util;

/**
 * Displays a page to grant users and teams access to a resource.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.view.security.GrantPermissionViewer",
	[dijit._Widget, dijit._Templated],	{
	
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/view/security/templates/GrantPermissionViewer.html"),
	
	constructor: function(args) {
		this._controller = args.controller;
		this._resource = args.resource;
		this._principalMap = args.principalMap;
		this._allPrincipals = args.allPrincipals;
		this._aclEntryPrincipals = args.aclEntryPrincipals;
		this._postSave = args.postSave;
		this._postCancel = args.postCancel;
	},
	
	postCreate: function() {
		Util.removeChildren(this.pageTitle);
		this.pageTitle.appendChild(document.createTextNode(SecurityMessages.GRANT_PERMISSION_VIEWER_PAGE_TITLE));
	
		Util.removeChildren(this.saveButton);
		this.saveButton.appendChild(document.createTextNode(CommonMessages.SAVE_BUTTON_LABEL));
		
		Util.removeChildren(this.closeButton);
		this.closeButton.appendChild(document.createTextNode(CommonMessages.CLOSE_BUTTON_LABEL));
		
		Util.removeChildren(this.resourceNameLabel);
		this.resourceNameLabel.appendChild(document.createTextNode(SecurityMessages.GRANT_PERMISSION_VIEWER_RESOURCE_NAME_LABEL));
		
		Util.removeChildren(this.resourceTypeLabel);
		this.resourceTypeLabel.appendChild(document.createTextNode(SecurityMessages.GRANT_PERMISSION_VIEWER_RESOURCE_TYPE_LABEL));
				
		this._msgFormatter = new MessageFormatter(this.messageArea);
		this._selectionWidget = null;
		
		var resourceNameText = document.createTextNode(this._resource.name);
		this.resourceName.appendChild(resourceNameText);
		
		var resourceTypeText = document.createTextNode(this._resource.type);
		this.resourceType.appendChild(resourceTypeText);			
		
		this._displayUserGroupSelections();
		
		var self = this;
		
		dojo.connect(this.saveButton, "onclick",
			function(e) {
				e.preventDefault();
				self._updateAclEntry();
			}
		);
		
		dojo.connect(this.closeButton, "onclick",
			function(e) {
				e.preventDefault();
				if (typeof self._postCancel != "undefined") {
					self._postCancel();
				}
			}
		);
	},
	
	_displayUserGroupSelections: function() {			
		this._msgFormatter.displayNoMessage();			
		
		var availableOptions = [];
		var selectedOptions = [];
		
		if (this._allPrincipals != null) {
			for (var i = 0; i < this._allPrincipals.length; i++ ) {
				var item = this._allPrincipals[i];
				availableOptions.push({value: item.name, text: item.name});
			}	
		}
		
		if (this._aclEntryPrincipals != null) {
			for (var i = 0; i < this._aclEntryPrincipals.length; i++ ) {
				var item = this._aclEntryPrincipals[i];
				selectedOptions.push({value: item.name, text: item.name});
			}	
		}
		
		this._selectionWidget = new com.ibm.rational.report.web.core.app.internal.common.SelectionWidget(
			{availableOptions: availableOptions, selectedOptions: selectedOptions,
			 //availableItemsTitle: "Deny Access To:", selectedItemsTitle: "Grant Access To:"});
			 availableItemsTitle: SecurityMessages.GRANT_PERMISSION_VIEWER_DENIED_ACCESS_TO_TITLE, selectedItemsTitle: SecurityMessages.GRANT_PERMISSION_VIEWER_GRANT_ACCESS_TO});
		this.userGroupSelections.appendChild(this._selectionWidget.domNode);
	},
	
	_updateAclEntry: function() {
		this._msgFormatter.displayNoMessage();
		
		var newPrincipals = this._selectionWidget.getAdded();
		if (newPrincipals != null && newPrincipals.length > 0) {
			var principalsIds = new Array();
			for (var i = 0; i < newPrincipals.length; i++) {
				principalsIds[i] = newPrincipals[i].value;
			}
			var permissionIds = new Array();
			
			var srh = new ServiceResponseHandler(this, "_postNewAclEntriesSuccess", "_getAllUsersError");
			var params = {type: this._resource.type, repositoryItemId: this._resource.itemId,
						  principalIds: principalsIds, permissionIds: permissionIds, negative: false};
			SecurityClient.postNewAclEntries(srh, params);
		}
		else {
			this._postNewAclEntriesSuccess();
		}
	},
	
	_postNewAclEntriesSuccess: function() {
		var removedPrincipals = this._selectionWidget.getRemoved();
		if (removedPrincipals != null && removedPrincipals.length > 0) {
			var principalsIds = new Array();
			for (var i = 0; i < removedPrincipals.length; i++ ) {
				principalsIds[i] = removedPrincipals[i].value;
			}
			
			var srh = new ServiceResponseHandler(this, "_postDeleteAclEntriesSuccess", "_getAllUsersError");
			SecurityClient.postDeleteAclEntriesWithPrincipals(srh, {principalIds: principalsIds});
		}
		else {
			this._postDeleteAclEntriesSuccess();
		}
	},
	
	_postDeleteAclEntriesSuccess: function() {
		if (typeof this._postSave != "undefined") {
			this._postSave();
		}
	},
	
	_getAllUsersError: function(error) {
		//this._msgFormatter.displayErrorMessage("VGRP0500E: Failed to retrieve users and teams from the server.", error);
		this._msgFormatter.displayErrorMessage(ServiceabilityMessages.FAILED_TO_RETRIEVE_USERS_AND_TEAMS, error);
		
	},	
	
	_postDeleteAclEntryError: function(error) {
		/*
		this._msgFormatter.displayErrorMessage("VGRP0521E: Failed to update the ACL entries for '"
			+ this._resource.name + "'.", error);
		*/
		var msg = dojo.string.substitute(ServiceabilityMessages.FAILED_TO_UPDATE_ACL_ENTRIES, [dojo.trim(this._resource.name)]);
		this._msgFormatter.displayErrorMessage(msg, error);
			
	},
	
	_done: function() {
		this._msgFormatter.displayNoMessage();
	}
});

})();